package guru.kake.ronove

import kotlin.reflect.KProperty1

/**
 * Class for holding the data of the entire translation project, which consists of pages consisting of lines.
 */
class Project {
    /** Pages of the project */
    var pages: MutableList<Page> = mutableListOf()
}

/**
 * Class for holding the data of a single translation page
 */
class Page(lines: Collection<Line> = listOf()) {
    /** Lines on a page */
    var lines: MutableList<Line> = lines.toMutableList()

    /**
     * Get a specific column of the page as a list
     * @param column the column to get, for example [Line::original]
     * @return list containing the elements of the column
     */
    fun getColumn(column: KProperty1<Line, String>) : List<String> = buildList {
        for (line in lines) add(column.get(line))
    }

    /**
     * Translates all lines on page
     */
    fun translatePage() {
        TranslationBackend(getColumn(Line::original)).zip(lines).forEach { (translation, line) ->
            line.machineTranslation = translation
        }
    }

    /**
     * Debug function for printing a page in stdout
     */
    @Deprecated("For debug use only", level = DeprecationLevel.WARNING)
    fun debugPrint() {
        for (line in lines) {
            println("${line.original}: ${line.machineTranslation}")
        }
    }
}

/**
 * Class for holding the data of a single line of translation
 */
data class Line(
    /** Original, untranslated text */
    var original: String = "",
    /** Machine translation of the original */
    var machineTranslation: String = "",
    /** Manual, finalized translation*/
    var finalTranslation: String = "",
    /** Translator notes for the line */
    var notes: String = ""
)