package guru.kake.ronove

import javafx.beans.property.ReadOnlyObjectProperty
import javafx.beans.property.SimpleIntegerProperty
import tornadofx.*

/**
 * Main class for the Ronove application
 */
class Ronove: App(MainView::class, RonoveStylesheet::class) {
    /** Current project data */
    var project = Project()

    /** Property for listening to changes on selected table view cell */
    var cellSelection: ReadOnlyObjectProperty<Line> = Line().toProperty()

    /** Currently selected page */
    var currentPage = SimpleIntegerProperty(1)

    /** Amount of pages in project */
    var pageCount = SimpleIntegerProperty(project.pages.size)

    /**
     * Change current page
     * @param page page to change to
     */
    fun changePage(page: Int) {
        currentPage.value = page
    }

    /**
     * Add new page to the end
     */
    fun addPage() {
        project.pages.add(Page())
        pageCount.set(project.pages.size)
    }

    companion object {
        /** Program main */
        @JvmStatic fun main(args: Array<String>) {
            launch<Ronove>(args)
        }
    }
}

